@@ -115,7 +115,7 @@ class DetectionParse:
                 category_id = gt.pop("categories")[0]["category_id"]
                 category_name = self.raw_class_info[gt_type][category_id]  # 拿到category_name
                 gt_item["category"] = self._class_domain.index(category_name)
-                attributes = gt.pop("attributes")
+                attributes = gt.pop("attributes", {})
                 for attr_k, attr_v in attributes.items():
                     attr_field = Field(attr_k, field_value=attr_v, is_attr=True)
                     object_struct.add_field(attr_field, optional=True)
